<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       http://nowebsite.yet
 * @since      1.0.0
 *
 * @package    Role_Based_Storage_Limiter
 * @subpackage Role_Based_Storage_Limiter/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Role_Based_Storage_Limiter
 * @subpackage Role_Based_Storage_Limiter/admin
 * @author     Marc Luther Capulong <mlccapulong@gmail.com>
 */
class Role_Based_Storage_Limiter_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Role_Based_Storage_Limiter_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Role_Based_Storage_Limiter_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/role-based-storage-limiter-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Role_Based_Storage_Limiter_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Role_Based_Storage_Limiter_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/role-based-storage-limiter-admin.js', array( 'jquery' ), $this->version, false );

	}

	/**
	 * Register the administration menu for this plugin into the WordPress Dashboard menu.
	 *
	 * @since    1.0.0
	 */
	public function add_plugin_admin_menu() {

	    /*
	     * Add a settings page for this plugin to the Settings menu.
	     *
	     * NOTE:  Alternative menu locations are available via WordPress administration menu functions.
	     *
	     *        Administration Menus: http://codex.wordpress.org/Administration_Menus
	     *
	     */
	    add_options_page( 'Role Based Storage Limiter Setup', 'Storage Limiter', 'manage_options', 'role-based-storage-limiter', array( $this, 'display_plugin_setup_page' ) );

	}

	 /**
	 * Add settings action link to the plugins page.
	 *
	 * @since    1.0.0
	 */
	public function add_action_links( $links ) {

	    /*
	    *  Documentation : https://codex.wordpress.org/Plugin_API/Filter_Reference/plugin_action_links_(plugin_file_name)
	    */
	   $settings_link = array( '<a href="' . admin_url( 'options-general.php?page=' . $this->plugin_name ) . '">' . __('Settings', $this->plugin_name) . '</a>' );
	   return array_merge(  $settings_link, $links );

	}

	/**
	 * Render the settings page for this plugin.
	 *
	 * @since    1.0.0
	 */
	public function display_plugin_setup_page() {
	    include_once( 'partials/role-based-storage-limiter-admin-display.php' );
	}

	/**
	 * Validates plugin option values before saving
	 *
	 * @since    1.0.0
	 * @param    array $input array of user input
	 * @return   array        array of validated user input
	 */
	public function validate( $input ) {

	    $valid = array();
	    $roles = wp_roles()->roles;

	    $role_limits = get_option( $this->plugin_name );

	    $input_has_error = false;

	    foreach ( $roles as $role_key => $role ) {
	    	if ( ctype_digit( $input[ $role_key ] ) || ( !ctype_digit( $input[ $role_key ] ) && $input[ $role_key ] === 'unlimited' ) ) {
	    		$valid[ $role_key ] = $input[ $role_key ];
	    	}
	    	else {
	    		$input_has_error = true;
	    	}
	    }

	    if ( $input_has_error ) {
	    	add_settings_error( 'rbsl_error', 'rbsl_error', 'Please enter numeric value or "unlimited" only.' );
	    	foreach ( $roles as $role_key => $role ) {
	    		$valid[ $role_key ] = $role_limits[ $role_key ];
	    	}
	    }

	    return $valid;

	}

	/**
	 * Updates plugin options
	 *
	 * @since    1.0.0
	 */
	public function options_update() {
	    register_setting( $this->plugin_name, $this->plugin_name, array( $this, 'validate' ) );
	}

}
